# ThermoWorks Cloud Python Client

![GitHub branch check runs](https://img.shields.io/github/check-runs/a2hill/python-thermoworks-cloud/main)
[![PyPI - Version](https://img.shields.io/pypi/v/thermoworks-cloud)](https://pypi.org/project/thermoworks-cloud/)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/thermoworks-cloud)
[![codecov](https://codecov.io/gh/a2hill/python-thermoworks-cloud/branch/main/graph/badge.svg?token=1QQENQPNB2)](https://codecov.io/gh/a2hill/python-thermoworks-cloud)
[![License](https://img.shields.io/github/license/a2hill/python-thermoworks-cloud)](https://raw.githubusercontent.com/a2hill/python-thermoworks-cloud/refs/heads/main/LICENSE.txt)

A Python client for the ThermoWorks Cloud API